import {useEffect, useState} from "react";
import PlantCard from "../components/PlantCard.tsx";
import DropDownFilter from "../components/DropDownFilter.tsx";

function Wunschliste() {
    const [plants, setPlants] = useState<any[]>([]);
    const [error, setError] = useState();

    const token: String = "";

    const [currentSort, setCurrentSort] = useState<string>("")

    useEffect(() => {
        fetch("http://localhost:8080/api/v1/wishlist?" + new URLSearchParams({sort: currentSort}),
            {
                method: 'GET',
                headers: {
                    "Content-Type": "application/json",
                    Authorization: `Bearer ${token}`,
                },
            })
            .then((res) => res.json())
            .then((plants) => setPlants(plants))
            .catch((err) => setError(err));
    }, [setPlants, currentSort]);

    const handleClearWishList = async () => {
        if (confirm("Möchtest du wirklich alle Pflanzen aus deiner Wunschliste entfernen?" + "\n" +
            "Diese Aktion kann nicht rückgängig gemacht werden.")) {
            useEffect(() => {
                fetch("http://localhost:8080/api/v1/wishlist/remove/all")
                    .then((res) => res.json())
                    .then((plants) => setPlants(plants))
                    .catch((err) => setError(err));
            }, [setPlants]);
        }
    }

    const handleSortOptions = async (selectedOption: string) => {
        switch (selectedOption) {
            case "neueste zuerst":
                setCurrentSort("createdAt");
                break;
            case "als nächstes anpflanzbar":
                setCurrentSort("plantDate");
                break;
            case "jetzt anpflanzbar":
                setCurrentSort("currentPlantable");
                break;
            default: setCurrentSort("");
        }
    }

    return (

        <>
            <div>
                <h2>Deine Wunschliste</h2>
                <DropDownFilter
                    topic={"Sortierung der Pflanzen in der Wunschliste"}
                    options={[
                        "neueste zuerst",
                        "als nächstes anpflanzbar",
                        "jetzt anpflanzbar",
                    ]}
                    filterOnChange={handleSortOptions}
                />
                <button onClick={handleClearWishList}>Wunschliste leeren</button>
            </div>
            {error ? (
                <p>Error fetching data</p>
            ) : (
                <ul style={{display: "flex", gap: "1rem", width: "100%"}}>
                    {plants?.map((plant) => (
                        <PlantCard plant={plant} key={plant.id}/>
                    ))}
                </ul>
            )}
        </>
    );
}


export default Wunschliste;

